<!DOCTYPE html>
<html>

<!-- Mirrored from html.yogsthemes.com/demo/banqix/price.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:00:47 GMT -->
<head>
<meta charset="utf-8">
<title>Banqix TV & Internet Business HTML-5 Template | Pricing</title>
<!-- Stylesheets -->
<link href="assets/css/bootstrap.css" rel="stylesheet">
<link href="assets/css/style.css" rel="stylesheet">
<link href="assets/css/meanmenu.min.css" rel="stylesheet">
<link href="assets/css/responsive.css" rel="stylesheet">

<!-- Color Switcher Mockup -->
<link href="assets/css/color-switcher-design.css" rel="stylesheet">

<!-- Color Themes -->
<link id="theme-color-file" href="assets/css/color-themes/default-color.css" rel="stylesheet">

<link href="https://fonts.googleapis.com/css2?family=Unbounded:wght@300;400;500;600;700;800;900&amp;display=swap" rel="stylesheet">
<link href="https://fonts.googleapis.com/css2?family=DM+Sans:opsz,wght@9..40,300;9..40,400;9..40,500;9..40,600;9..40,700;9..40,800;9..40,900&amp;display=swap" rel="stylesheet">

<link rel="shortcut icon" href="assets/images/favicon.png" type="image/x-icon">
<link rel="icon" href="assets/images/favicon.png" type="image/x-icon">

<!-- Responsive -->
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0">

<!--[if lt IE 9]><script src="https://cdnjs.cloudflare.com/ajax/libs/html5shiv/3.7.3/html5shiv.js"></script><![endif]-->
<!--[if lt IE 9]><script src="js/respond.js"></script><![endif]-->
</head>

<body>

<div class="page-wrapper">
	
	<!-- Cursor -->
	<div class="cursor"></div>
	<div class="cursor-follower"></div>
	<!-- Cursor End -->
 	
	<!-- Preloader -->
    <div class="preloader"></div>
	<!-- End Preloader -->
	
	<!-- Main Header / Header Style Four -->
	<header class="main-header header-style-four">
		
		<!-- Header Upper -->
		<div class="header-upper" style="background-image:url(assets/images/background/4.jpg)">
			<div class="auto-container">
				<div class="d-flex justify-content-between align-items-center flex-wrap">
					<!-- Info List -->
					<ul class="header-top_list-two d-flex align-items-center flex-wrap">
						<li><span class="icon fa-solid fa-clock fa-fw"></span>Mon-Fri : 9am to 6pm</li>
						<li><span class="icon fa-solid fa-envelope fa-fw"></span>needhelp@company.com</li>
					</ul>

					<!-- Logo -->
					<div class="logo"><a href="index.html"><img src="assets/images/logo.png" alt="" title=""></a></div>

					<div class="right-box d-flex align-items-center flex-wrap">

						<!-- Language DropDown -->
						<div class="language-dropdown">
							<button class="btn dropdown-toggle" type="button" id="dropdownMenuButton1" data-bs-toggle="dropdown" aria-expanded="false">
								<span class="flag"><img src="assets/images/icons/flag.png" alt="" /></span> English &nbsp;<span class="fa-solid fa-angle-down fa-fw"></span>
							  </button>
							<ul class="dropdown-menu" aria-labelledby="dropdownMenuButton1">
								<li><a class="dropdown-item" href="#">English</a></li>
								<li><a class="dropdown-item" href="#">Arbic</a></li>
								<li><a class="dropdown-item" href="#">German</a></li>
								<li><a class="dropdown-item" href="#">French</a></li>
							</ul>
						</div>

						<!-- Header Search Box -->
						<div class="header-search_box">
							<form method="post" action="https://html.yogsthemes.com/demo/banqix/contact.html">
								<div class="form-group">
									<input type="search" name="search-field" value="" placeholder="I’m Looking for..." required>
									<button type="submit"><span class="icon fa fa-search"></span></button>
								</div>
							</form>
						</div>

					</div>

				</div>
			</div>
		</div>

		<!-- Header Upper -->
		<div class="header-lower">
			<div class="auto-container">
				<div class="inner-container">
					<div class="d-flex justify-content-between align-items-center flex-wrap">
						
						<!-- Header Two Socials -->
						<div class="header-two_socials">
							<a class="fa-brands fa-facebook-f fa-fw" href="#"></a>
							<a class="fa-brands fa-instagram fa-fw" href="#"></a>
							<a class="fa-brands fa-twitter fa-fw" href="#"></a>
							<a class="fa-brands fa-youtube fa-fw" href="#"></a>
						</div>
						
						<div class="nav-outer d-flex flex-wrap">
							<!-- Main Menu -->
							<nav class="main-menu navbar-expand-md">
								<div class="navbar-header">
									<!-- Toggle Button -->    	
									<button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
										<span class="icon-bar"></span>
										<span class="icon-bar"></span>
										<span class="icon-bar"></span>
									</button>
								</div>
								
								<div class="navbar-collapse collapse clearfix" id="navbarSupportedContent">
									<ul class="navigation clearfix">
										<li class="dropdown"><a href="#">Home</a>
											<ul>
												<li><a href="index.html">Homepage 01</a></li>
												<li><a href="index-2.html">Homepage 02</a></li>
												<li><a href="index-3.html">Homepage 03</a></li>
												<li><a href="index-4.html">Homepage 04</a></li>
												<li class="dropdown"><a href="#">Header Styles</a>
													<ul>
														<li><a href="index.html">Header 01</a></li>
														<li><a href="index-2.html">Header 02</a></li>
														<li><a href="index-3.html">Header 03</a></li>
														<li><a href="index-4.html">Header 04</a></li>
													</ul>
												</li>
											</ul>
										</li>
										<li class="dropdown"><a href="#">About</a>
											<ul>
												<li><a href="about.html">About us</a></li>
												<li><a href="faq.html">Faq</a></li>
												<li><a href="price.html">price</a></li>
												<li><a href="privacy.html">Privacy Policy</a></li>
												<li><a href="terms.html">Terms & Condition</a></li>
												<li class="dropdown"><a href="#">Team</a>
													<ul>
														<li><a href="team.html">Team</a></li>
														<li><a href="team-detail.html">Team Detail</a></li>
													</ul>
												</li>
											</ul>
										</li>
										<li class="dropdown"><a href="#">service</a>
											<ul>
												<li><a href="services.html">Services</a></li>
												<li><a href="service-detail.html">service detail</a></li>
											</ul>
										</li>
										<li class="dropdown"><a href="#">shop</a>
											<ul>
												<li><a href="shop.html">shop</a></li>
												<li><a href="shop-detail.html">shop detail</a></li>
												<li><a href="coming-soon.html">coming soon</a></li>
											</ul>
										</li>
										<li class="dropdown"><a href="#">Blog</a>
											<ul>
												<li><a href="blog.html">Our Blog</a></li>
												<li><a href="blog-detail.html">Blog Detail</a></li>
												<li><a href="not-found.html">Not Found</a></li>
											</ul>
										</li>
										<li><a href="contact.html">Contact</a></li>
									</ul>
								</div>
							</nav>
						</div>

						<!-- Main Menu End-->
						<div class="outer-box d-flex align-items-center flex-wrap">
							
							<!-- Login Box -->
							<a class="header-login_box" href="#">
								<i class="fa-regular fa-user fa-fw"></i>
							</a>

							<!-- Nav Btn -->
							<div class="nav-btn navSidebar-button">
								<i class="fas fa-shopping-cart fa-fw"></i>
								<span>2</span>
							</div>

							<!-- About Widget -->
							<span class="about-widget">
								<img src="assets/images/icons/grid-icon.png" alt="" />
							</span>

							<!-- Mobile Navigation Toggler -->
							<div class="mobile-nav-toggler"><span class="icon flaticon-menu"></span></div>
						</div>
						
					</div>
				</div>
			</div>
		</div>
		<!--End Header Upper-->
		
		<!-- Mobile Menu  -->
		<div class="mobile-menu">
			<div class="menu-backdrop"></div>
			<div class="close-btn"><span class="icon flaticon-multiply"></span></div>
			
			<nav class="menu-box">
				<div class="nav-logo"><a href="index.html"><img src="assets/images/logo.png" alt="" title=""></a></div>
				<div class="menu-outer"><!--Here Menu Will Come Automatically Via Javascript / Same Menu as in Header--></div>
			</nav>
		</div>
		<!-- End Mobile Menu -->
	
	</header>
	<!-- End Main Header / Header Four -->
	
	<!-- Sidebar Cart Item -->
	<div class="xs-sidebar-group info-group">
		<div class="xs-overlay xs-bg-black"></div>
		<div class="xs-sidebar-widget">
			<div class="sidebar-widget-container">
				<div class="close-button">
					<span class="fa-solid fa-xmark fa-fw"></span>
				</div>
				<div class="sidebar-textwidget">
					
					<!-- Sidebar Info Content -->
					<div class="sidebar-info-contents">
						<div class="content-inner">
						
							<!-- Title Box -->
							<div class="title-box">
								<h5>Broadband <span>connection</span></h5>
								<div class="price">$15 from free economy shipping</div>
							</div>
							
							<!-- Empty Cart Box -->
							<div class="empty-cart-box">
								<!-- No Product -->
								<div class="no-cart">
									<span class="icon fa-solid fa-cart-flatbed-suitcase fa-fw"></span>
									No products in cart.
								</div>
							</div>
							
							<!-- Lower Box -->
							<div class="lower-box">
								<h5>Popular <span>Suggestions</span></h5>
									
								<!-- Post Block -->
								<div class="post-block">
									<div class="inner-box">
										<div class="image">
											<img src="assets/images/resource/post-thumb-1.jpg" alt="" />
										</div>
										<h6><a href="#">Free Installation</a></h6>
										<div class="rating">
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
										</div>
										<div class="price-box">$125</div>
										<a class="theme-btn bag-btn" href="#">add to bag</a>
									</div>
								</div>
								
								<!-- Post Block -->
								<div class="post-block">
									<div class="inner-box">
										<div class="image">
											<img src="assets/images/resource/post-thumb-2.jpg" alt="" />
										</div>
										<h6><a href="#">Ultra Fast Connect</a></h6>
										<div class="rating">
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
										</div>
										<div class="price-box">$205</div>
										<a class="theme-btn bag-btn" href="#">add to bag</a>
									</div>
								</div>
								
								<!-- Post Block -->
								<div class="post-block">
									<div class="inner-box">
										<div class="image">
											<img src="assets/images/resource/post-thumb-3.jpg" alt="" />
										</div>
										<h6><a href="#">4K and 8K Quality</a></h6>
										<div class="rating">
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
										</div>
										<div class="price-box">$25</div>
										<a class="theme-btn bag-btn" href="#">add to bag</a>
									</div>
								</div>
								
							</div>
							
						</div>
					</div>
					
				</div>
			</div>
		</div>
	</div>
	<!-- End Sidebar Cart Item -->

	<!-- About Sidebar -->
	<div class="about-sidebar">
		<div class="gradient-layer"></div>
		<!-- Close Button -->
		<div class="close-sidebar-widget close-button">
			<span class="fa-solid fa-xmark fa-fw"></span>
		</div>
		<div class="sidebar-inner">
			<div class="upper-box">
				<div class="image">
					<img src="assets/images/resource/about-1.jpg" alt="" />
				</div>
				<div class="content-box">
					<h3>About <span>Monic</span></h3>
					<div class="text">Many desktop Wifi packages & web page editors now use Ipsum budgets dipiscing</div>
					<ul class="about-one_list">
						<li>Internet with 50 Mbps</li>
						<li>Night Turbo-Speed</li>
						<li>WiFi router & prevention</li>
						<li>Unlimited devices</li>
					</ul>
				</div>
			</div>
			<!-- Social Box -->
			<div class="social-box">
				<a href="https://facebook.com/"><i class="fa-brands fa-facebook-f"></i></a>
				<a href="https://twitter.com/"><i class="fa-brands fa-twitter"></i></a>
				<a href="https://youtube.com/"><i class="fa-brands fa-youtube"></i></a>
				<a href="https://instagram.com/"><i class="fa-brands fa-instagram"></i></a>
			</div>
		</div>
	</div>
	<!-- End About Sidebar -->

	<!-- Page Title -->
    <section class="page-title" style="background-image:url(assets/images/background/pattern-19.png)">
        <div class="auto-container">
			<h2>Pricing</h2>
			<ul class="bread-crumb clearfix">
				<li><a href="index.html">Home</a></li>
				<li>Pricing</li>
			</ul>
			<div class="page-title_side-image">
				<span class="page-title_color-one"></span>
				<span class="page-title_color-two"></span>
				<img src="assets/images/resource/page-title.jpg" alt="" />
			</div>
        </div>
    </section>
    <!-- End Page Title -->

	<!-- Price Two -->
	<section class="price-two">
		<div class="price-two_pattern-one" style="background-image:url(assets/images/background/pattern-7.png)"></div>
		<div class="price-two_pattern-two" style="background-image:url(assets/images/background/pattern-10.png)"></div>
		<div class="price-two_pattern-three" style="background-image:url(assets/images/background/pattern-9.png)"></div>
		<div class="auto-container_two">
			<div class="inner-container">
				<div class="price-two_pattern-four" style="background-image:url(assets/images/background/pattern-8.png)"></div>
				<!-- Sec Title -->
				<div class="sec-title centered">
					<div class="sec-title_title title-anim">Prices Plan</div>
					<h2 class="sec-title_heading">our best pricing plan <br> for you</h2>
				</div>
				<div class="row clearfix">

					<!-- Price Block Two -->
					<div class="price-block_two col-lg-4 col-md-6 col-sm-12">
						<div class="price-block_two-inner">

							<!-- Price Tabs -->
							<div class="price_tabs">
								<!-- Price Tabs -->
								<div class="price_tab tabs-box">
								
									<!-- Tabs Container -->
									<div class="tabs-content">
										
										<!-- Tab -->
										<div class="tab" id="price-one">
											<div class="price-block_two-content">
												<div class="price-block_two-image-layer" style="background-image:url(assets/images/background/price-two_bg.jpg)"></div>
												<div class="price-block_two-price">$56<span>/ per month</span></div>
												<div class="price-block_two-tax">Internet, TV & Phone</div>
												<h3 class="price-block_two-title">Premium plan</h3>
												<ul class="price-block_two-list">
													<li>200 Mbps internet <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Night Turbo-Speed <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Connect Multiple Users <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Wifi Router & Prevention <i class="remove fa-solid fa-xmark fa-fw"></i></li>
												</ul>
												<div class="price-block_two-button">
													<a href="price.html" class="theme-btn btn-style-two">
														<span class="btn-wrap">
															<span class="text-one">get started <i class="fa-solid fa-plus fa-fw"></i></span>
															<span class="text-two">get started <i class="fa-solid fa-plus fa-fw"></i></span>
														</span>
													</a>
												</div>
											</div>
										</div>

										<!-- Tab -->
										<div class="tab active-tab" id="price-two">
											<div class="price-block_two-content">
												<div class="price-block_two-image-layer" style="background-image:url(assets/images/background/price-two_bg.jpg)"></div>
												<div class="price-block_two-price">$76<span>/ per month</span></div>
												<div class="price-block_two-tax">Internet, TV & Phone</div>
												<h3 class="price-block_two-title">Premium plan</h3>
												<ul class="price-block_two-list">
													<li>200 Mbps internet <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Night Turbo-Speed <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Connect Multiple Users <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Wifi Router & Prevention <i class="remove fa-solid fa-xmark fa-fw"></i></li>
												</ul>
												<div class="price-block_two-button">
													<a href="price.html" class="theme-btn btn-style-two">
														<span class="btn-wrap">
															<span class="text-one">get started <i class="fa-solid fa-plus fa-fw"></i></span>
															<span class="text-two">get started <i class="fa-solid fa-plus fa-fw"></i></span>
														</span>
													</a>
												</div>
											</div>
										</div>

										<!-- Tab -->
										<div class="tab" id="price-three">
											<div class="price-block_two-content">
												<div class="price-block_two-image-layer" style="background-image:url(assets/images/background/price-two_bg.jpg)"></div>
												<div class="price-block_two-price">$96<span>/ per month</span></div>
												<div class="price-block_two-tax">Internet, TV & Phone</div>
												<h3 class="price-block_two-title">Premium plan</h3>
												<ul class="price-block_two-list">
													<li>200 Mbps internet <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Night Turbo-Speed <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Connect Multiple Users <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Wifi Router & Prevention <i class="remove fa-solid fa-xmark fa-fw"></i></li>
												</ul>
												<div class="price-block_two-button">
													<a href="price.html" class="theme-btn btn-style-two">
														<span class="btn-wrap">
															<span class="text-one">get started <i class="fa-solid fa-plus fa-fw"></i></span>
															<span class="text-two">get started <i class="fa-solid fa-plus fa-fw"></i></span>
														</span>
													</a>
												</div>
											</div>
										</div>

									</div>

									<!-- Tab Btns -->
									<ul class="tab-btns tab-buttons clearfix">
										<li data-tab="#price-one" class="tab-btn">
											<i class="flaticon-technology"></i>
										</li>
										<li data-tab="#price-two" class="tab-btn active-btn">
											<i class="flaticon-globe-grid"></i>
										</li>
										<li data-tab="#price-three" class="tab-btn">
											<i class="flaticon-wifi-2"></i>
										</li>
									</ul>

								</div>
							</div>
							
						</div>
					</div>

					<!-- Price Block Two -->
					<div class="price-block_two col-lg-4 col-md-6 col-sm-12">
						<div class="price-block_two-inner">

							<!-- Price Tabs -->
							<div class="price_tabs">
								<!-- Price Tabs -->
								<div class="price_tab tabs-box">
								
									<!-- Tabs Container -->
									<div class="tabs-content">
										
										<!-- Tab -->
										<div class="tab" id="price-four">
											<div class="price-block_two-content">
												<div class="price-block_two-image-layer" style="background-image:url(assets/images/background/price-two_bg.jpg)"></div>
												<div class="price-block_two-price">$86<span>/ per month</span></div>
												<div class="price-block_two-tax">Internet, TV & Phone</div>
												<h3 class="price-block_two-title">Standard plan</h3>
												<ul class="price-block_two-list">
													<li>200 Mbps internet <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Night Turbo-Speed <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Connect Multiple Users <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Wifi Router & Prevention <i class="remove fa-solid fa-xmark fa-fw"></i></li>
												</ul>
												<div class="price-block_two-button">
													<a href="price.html" class="theme-btn btn-style-two">
														<span class="btn-wrap">
															<span class="text-one">get started <i class="fa-solid fa-plus fa-fw"></i></span>
															<span class="text-two">get started <i class="fa-solid fa-plus fa-fw"></i></span>
														</span>
													</a>
												</div>
											</div>
										</div>

										<!-- Tab -->
										<div class="tab active-tab" id="price-five">
											<div class="price-block_two-content">
												<div class="price-block_two-image-layer" style="background-image:url(assets/images/background/price-two_bg.jpg)"></div>
												<div class="price-block_two-price">$86<span>/ per month</span></div>
												<div class="price-block_two-tax">Internet, TV & Phone</div>
												<h3 class="price-block_two-title">Standard plan</h3>
												<ul class="price-block_two-list">
													<li>200 Mbps internet <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Night Turbo-Speed <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Connect Multiple Users <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Wifi Router & Prevention <i class="remove fa-solid fa-xmark fa-fw"></i></li>
												</ul>
												<div class="price-block_two-button">
													<a href="price.html" class="theme-btn btn-style-two">
														<span class="btn-wrap">
															<span class="text-one">get started <i class="fa-solid fa-plus fa-fw"></i></span>
															<span class="text-two">get started <i class="fa-solid fa-plus fa-fw"></i></span>
														</span>
													</a>
												</div>
											</div>
										</div>

										<!-- Tab -->
										<div class="tab" id="price-six">
											<div class="price-block_two-content">
												<div class="price-block_two-image-layer" style="background-image:url(assets/images/background/price-two_bg.jpg)"></div>
												<div class="price-block_two-price">$86<span>/ per month</span></div>
												<div class="price-block_two-tax">Internet, TV & Phone</div>
												<h3 class="price-block_two-title">Standard plan</h3>
												<ul class="price-block_two-list">
													<li>200 Mbps internet <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Night Turbo-Speed <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Connect Multiple Users <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Wifi Router & Prevention <i class="remove fa-solid fa-xmark fa-fw"></i></li>
												</ul>
												<div class="price-block_two-button">
													<a href="price.html" class="theme-btn btn-style-two">
														<span class="btn-wrap">
															<span class="text-one">get started <i class="fa-solid fa-plus fa-fw"></i></span>
															<span class="text-two">get started <i class="fa-solid fa-plus fa-fw"></i></span>
														</span>
													</a>
												</div>
											</div>
										</div>

									</div>

									<!-- Tab Btns -->
									<ul class="tab-btns tab-buttons clearfix">
										<li data-tab="#price-four" class="tab-btn">
											<i class="flaticon-technology"></i>
										</li>
										<li data-tab="#price-five" class="tab-btn active-btn">
											<i class="flaticon-globe-grid"></i>
										</li>
										<li data-tab="#price-six" class="tab-btn">
											<i class="flaticon-wifi-2"></i>
										</li>
									</ul>

								</div>
							</div>
							
						</div>
					</div>

					<!-- Price Block Two -->
					<div class="price-block_two col-lg-4 col-md-6 col-sm-12">
						<div class="price-block_two-inner">

							<!-- Price Tabs -->
							<div class="price_tabs">
								<!-- Price Tabs -->
								<div class="price_tab tabs-box">
								
									<!-- Tabs Container -->
									<div class="tabs-content">
										
										<!-- Tab -->
										<div class="tab" id="price-seven">
											<div class="price-block_two-content">
												<div class="price-block_two-image-layer" style="background-image:url(assets/images/background/price-two_bg.jpg)"></div>
												<div class="price-block_two-price">$96<span>/ per month</span></div>
												<div class="price-block_two-tax">Internet, TV & Phone</div>
												<h3 class="price-block_two-title">Business plan</h3>
												<ul class="price-block_two-list">
													<li>200 Mbps internet <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Night Turbo-Speed <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Connect Multiple Users <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Wifi Router & Prevention <i class="remove fa-solid fa-xmark fa-fw"></i></li>
												</ul>
												<div class="price-block_two-button">
													<a href="price.html" class="theme-btn btn-style-two">
														<span class="btn-wrap">
															<span class="text-one">get started <i class="fa-solid fa-plus fa-fw"></i></span>
															<span class="text-two">get started <i class="fa-solid fa-plus fa-fw"></i></span>
														</span>
													</a>
												</div>
											</div>
										</div>

										<!-- Tab -->
										<div class="tab active-tab" id="price-eight">
											<div class="price-block_two-content">
												<div class="price-block_two-image-layer" style="background-image:url(assets/images/background/price-two_bg.jpg)"></div>
												<div class="price-block_two-price">$96<span>/ per month</span></div>
												<div class="price-block_two-tax">Internet, TV & Phone</div>
												<h3 class="price-block_two-title">Business plan</h3>
												<ul class="price-block_two-list">
													<li>200 Mbps internet <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Night Turbo-Speed <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Connect Multiple Users <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Wifi Router & Prevention <i class="remove fa-solid fa-xmark fa-fw"></i></li>
												</ul>
												<div class="price-block_two-button">
													<a href="price.html" class="theme-btn btn-style-two">
														<span class="btn-wrap">
															<span class="text-one">get started <i class="fa-solid fa-plus fa-fw"></i></span>
															<span class="text-two">get started <i class="fa-solid fa-plus fa-fw"></i></span>
														</span>
													</a>
												</div>
											</div>
										</div>

										<!-- Tab -->
										<div class="tab" id="price-nine">
											<div class="price-block_two-content">
												<div class="price-block_two-image-layer" style="background-image:url(assets/images/background/price-two_bg.jpg)"></div>
												<div class="price-block_two-price">$96<span>/ per month</span></div>
												<div class="price-block_two-tax">Internet, TV & Phone</div>
												<h3 class="price-block_two-title">Business plan</h3>
												<ul class="price-block_two-list">
													<li>200 Mbps internet <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Night Turbo-Speed <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Connect Multiple Users <i class="fa-solid fa-check fa-fw"></i></li>
													<li>Wifi Router & Prevention <i class="remove fa-solid fa-xmark fa-fw"></i></li>
												</ul>
												<div class="price-block_two-button">
													<a href="price.html" class="theme-btn btn-style-two">
														<span class="btn-wrap">
															<span class="text-one">get started <i class="fa-solid fa-plus fa-fw"></i></span>
															<span class="text-two">get started <i class="fa-solid fa-plus fa-fw"></i></span>
														</span>
													</a>
												</div>
											</div>
										</div>

									</div>

									<!-- Tab Btns -->
									<ul class="tab-btns tab-buttons clearfix">
										<li data-tab="#price-seven" class="tab-btn">
											<i class="flaticon-technology"></i>
										</li>
										<li data-tab="#price-eight" class="tab-btn active-btn">
											<i class="flaticon-globe-grid"></i>
										</li>
										<li data-tab="#price-nine" class="tab-btn">
											<i class="flaticon-wifi-2"></i>
										</li>
									</ul>

								</div>
							</div>
							
						</div>
					</div>

				</div>
			</div>
		</div>
	</section>
	<!-- End Price Two -->

	<!-- Footer Style Two -->
	<footer class="footer-style_two">
		<div class="footer-style_two-image alternate" style="background-image:url(assets/images/background/2.jpg)"></div>
		<div class="auto-container_two">
			<!-- Upper Box -->
			<div class="upper-box">
				<div class="row clearfix">
					
					<!-- Logo Column -->
					<div class="footer-two_logo-column col-lg-6 col-md-12 col-sm-12">
						<div class="logo"><a href="index.html"><img src="assets/images/logo-3.png" alt="" title=""></a></div>
						<!-- Social Box -->
						<div class="footer-two_socials">
							<a href="https://facebook.com/"><i class="fa-brands fa-facebook-f"></i></a>
							<a href="https://twitter.com/"><i class="fa-brands fa-twitter"></i></a>
							<a href="https://youtube.com/"><i class="fa-brands fa-youtube"></i></a>
							<a href="https://instagram.com/"><i class="fa-brands fa-instagram"></i></a>
						</div>
					</div>

					<!-- Subscribe Column -->
					<div class="footer-two_subscribe-column col-lg-6 col-md-12 col-sm-12">
						<div class="inner-column">
							<h4>Sign up to get latest <br> Updates</h4>
							<div class="text">Latest news, AI models & fun memes from the community.</div>
							<div class="subscribe-box">
								<form method="post" action="https://html.yogsthemes.com/demo/banqix/contact.html">
									<div class="form-group">
										<input type="email" name="search-field" value="" placeholder="Enter Your Email" required>
										<button type="submit" class="theme-btn btn-style-one">
											<span class="btn-wrap">
												<span class="text-one">Subscribe Now <i class="fa-solid fa-plus fa-fw"></i></span>
												<span class="text-two">Subscribe Now <i class="fa-solid fa-plus fa-fw"></i></span>
											</span>
										</button>
									</div>
								</form>
							</div>
						</div>
					</div>

				</div>
			</div>
			<!-- Widgets Section -->
			<div class="widgets-section">
				<div class="row clearfix">

					<!-- Footer Column -->
					<div class="footer_column col-lg-4 col-md-6 col-sm-12">
						<div class="footer-widget gallery-widget">
							<h4 class="footer-title">Service Schedule</h4>
							<ul class="timing-list">
								<li>Mon-Tues<span>03.00AM - 08.00PM</span></li>
								<li>Wedne-Thur<span>07.00AM - 09.00PM</span></li>
								<li>Fri-Sat<span>06.00AM - 11.00PM</span></li>
							</ul>
						</div>
					</div>

					<!-- Footer Column -->
					<div class="footer_column col-lg-4 col-md-6 col-sm-12">
						<div class="footer-widget lists-widget">
							<h4 class="footer-title">Get Free Link</h4>
							<ul class="footer-list_two">
								<li><a href="#">IT Consulting</a></li>
								<li><a href="#">Others</a></li>
								<li><a href="#">Data Analytics</a></li>
								<li><a href="#">UI & UX Design</a></li>
								<li><a href="#">Network Solutions</a></li>
								<li><a href="#">Software Development</a></li>
							</ul>
						</div>
					</div>

					<!-- Footer Column -->
					<div class="footer_column col-lg-4 col-md-6 col-sm-12">
						<div class="footer-widget instagram-widget">
							<h4 class="footer-title">Instagram</h4>
							<div class="images-outer clearfix">
								<!--Image Box-->
								<figure class="image-box"><a class="lightbox-image" href="assets/images/gallery/1.jpg"><img src="assets/images/gallery/instagram-1.jpg" alt=""></a></figure>
								<!--Image Box-->
								<figure class="image-box"><a class="lightbox-image" href="assets/images/gallery/2.jpg"><img src="assets/images/gallery/instagram-2.jpg" alt=""></a></figure>
								<!--Image Box-->
								<figure class="image-box"><a class="lightbox-image" href="assets/images/gallery/3.jpg"><img src="assets/images/gallery/instagram-3.jpg" alt=""></a></figure>
								<!--Image Box-->
								<figure class="image-box"><a class="lightbox-image" href="assets/images/gallery/1.jpg"><img src="assets/images/gallery/instagram-1.jpg" alt=""></a></figure>
								<!--Image Box-->
								<figure class="image-box"><a class="lightbox-image" href="assets/images/gallery/2.jpg"><img src="assets/images/gallery/instagram-2.jpg" alt=""></a></figure>
								<!--Image Box-->
								<figure class="image-box"><a class="lightbox-image" href="assets/images/gallery/3.jpg"><img src="assets/images/gallery/instagram-3.jpg" alt=""></a></figure>
							</div>
						</div>
					</div>

				</div>
			</div>

			<div class="footer-bottom">
				<div class="d-flex justify-content-between align-items-center flex-wrap">

					<ul class="footer-bottom_nav">
						<li><a href="#">Policy & Privacy</a></li>
						<li><a href="#">Terms & Condition</a></li>
					</ul>

					<!-- Copyright -->
					<div class="main-footer_copyright">Copyright &copy; 2023. All Rights Reserved.</div>

				</div>
			</div>

		</div>
	</footer>
	<!-- End Footer Style Two -->

	<!-- Search Popup -->
	<div class="search-popup">
		<div class="color-layer"></div>
		<button class="close-search"><span class="flaticon-close-1"></span></button>
		<form method="post" action="https://html.yogsthemes.com/demo/banqix/blog.html">
			<div class="form-group">
				<input type="search" name="search-field" value="" placeholder="Search Here" required="">
				<button class="fa fa-solid fa-magnifying-glass fa-fw" type="submit"></button>
			</div>
		</form>
	</div>
	<!-- End Search Popup -->
	
	<!-- Color Palate / Color Switcher -->
	<div class="color-palate">
		<div class="color-trigger">
			<i class="fa fa-solid fa-gear fa-fw"></i>
		</div>
		<div class="color-palate-inner">
			<div class="color-palate-head">
				<h6>Choose Options</h6>
			</div>
			
			<!-- Colors -->
			<div class="various-color clearfix">
				<div class="colors-list">
					<span class="palate default-color active" data-theme-file="assets/css/color-themes/default-color.css"></span>
					<span class="palate blue-color" data-theme-file="assets/css/color-themes/blue-color.css"></span>
					<span class="palate olive-color" data-theme-file="assets/css/color-themes/olive-color.css"></span>
					<span class="palate orange-color" data-theme-file="assets/css/color-themes/orange-color.css"></span>
					<span class="palate purple-color" data-theme-file="assets/css/color-themes/purple-color.css"></span>
					<span class="palate green-color" data-theme-file="assets/css/color-themes/green-color.css"></span>
					<span class="palate brown-color" data-theme-file="assets/css/color-themes/brown-color.css"></span>
					<span class="palate yellow-color" data-theme-file="assets/css/color-themes/yellow-color.css"></span>
				</div>
			</div>
					
			<h6>RTL Version</h6>
			<ul class="rtl-version option-box"> <li class="rtl">RTL Version</li> <li>LTR Version</li> </ul>
			<h6>Want Sticky Header</h6>
			<ul class="header-version option-box"> <li class="box">No</li> <li>Yes</li></ul>
			<h6>Dark Verion</h6>
			<ul class="dark-version option-box"> <li class="box">Yes</li> <li>No</li></ul>
			
			<div class="purchase-box">
				You will find much more options for colors and styling in admin panel. This color picker is used only for demonstation purposes.
				<a href="#" class="theme-btn btn-style-two">
					<span class="btn-wrap">
						<span class="text-one">buy now</span>
						<span class="text-two">buy now</span>
					</span>
				</a>
			</div>
			
		</div>
	</div>
	<!-- End Color Palate / Color Switcher -->
	
</div>
<!-- End PageWrapper -->

<div class="progress-wrap">
	<svg class="progress-circle svg-content" width="100%" height="100%" viewBox="-1 -1 102 102">
		<path d="M50,1 a49,49 0 0,1 0,98 a49,49 0 0,1 0,-98"/>
	</svg>
</div>

<script src="assets/js/jquery.js"></script>
<script src="assets/js/popper.min.js"></script>
<script src="assets/js/bootstrap.min.js"></script>
<script src="assets/js/appear.js"></script>
<script src="assets/js/parallax.min.js"></script>
<script src="assets/js/tilt.jquery.min.js"></script>
<script src="assets/js/jquery.paroller.min.js"></script>
<script src="assets/js/wow.js"></script>
<script src="assets/js/swiper.min.js"></script>
<script src="assets/js/backtotop.js"></script>
<script src="assets/js/odometer.js"></script>
<script src="assets/js/parallax-scroll.js"></script>

<script src="assets/js/gsap.min.js"></script>
<script src="assets/js/SplitText.min.js"></script>
<script src="assets/js/ScrollTrigger.min.js"></script>
<script src="assets/js/ScrollToPlugin.min.js"></script>
<script src="assets/js/ScrollSmoother.min.js"></script>

<script src="assets/js/magnific-popup.min.js"></script>
<script src="assets/js/jquery.meanmenu.min.js"></script>
<script src="assets/js/nav-tool.js"></script>
<script src="assets/js/jquery-ui.js"></script>
<script src="assets/js/element-in-view.js"></script>
<script src="assets/js/color-settings.js"></script>
<script src="assets/js/script.js"></script>

</body>

<!-- Mirrored from html.yogsthemes.com/demo/banqix/price.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:00:47 GMT -->
</html>